@@ -10,7 +10,7 @@ setwd( system.file("test", package="RVowpalWabbit") )
 # {VW} -t train-sets/0001.dat -i models/0001.model -p 001.predict.tmp
 test2 <- c("-t", "train-sets/0001.dat",
            "-i", "models/0001.model",
-           "-p", "/tmp/0001.predict.tmp")
+           "-p", file.path(tempdir(), "0001.predict.tmp"))
 
 res <- vw(test2, quiet=FALSE)
 print(res)
